package com.mdd.admin.config.quartz;

import com.mdd.common.entity.Crontab;
import com.mdd.common.util.SpringUtils;
import com.mdd.common.util.StringUtils;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class InvokeUtils {
   public static void invokeMethod(Crontab crontab) throws Exception {
      String invokeTarget = crontab.getCommand();
      String beanName = getBeanName(invokeTarget);
      String methodName = getMethodName(invokeTarget);
      List<Object[]> methodParams = getMethodParams(invokeTarget);
      Object bean;
      if (!isValidClassName(beanName)) {
         bean = SpringUtils.getBean(beanName);
         invokeMethod(bean, methodName, methodParams);
      } else {
         bean = Class.forName(beanName).newInstance();
         invokeMethod(bean, methodName, methodParams);
      }

   }

   private static void invokeMethod(Object bean, String methodName, List<Object[]> methodParams) throws NoSuchMethodException, SecurityException, IllegalAccessException, IllegalArgumentException, InvocationTargetException {
      Method method;
      if (StringUtils.isNotNull(methodParams) && methodParams.size() > 0) {
         method = bean.getClass().getMethod(methodName, getMethodParamsType(methodParams));
         method.invoke(bean, getMethodParamsValue(methodParams));
      } else {
         method = bean.getClass().getMethod(methodName);
         method.invoke(bean);
      }

   }

   public static boolean isValidClassName(String invokeTarget) {
      return StringUtils.countMatches(invokeTarget, ".") > 1;
   }

   public static String getBeanName(String invokeTarget) {
      String beanName = StringUtils.substringBefore(invokeTarget, "(");
      return StringUtils.substringBeforeLast(beanName, ".");
   }

   public static String getMethodName(String invokeTarget) {
      String methodName = StringUtils.substringBefore(invokeTarget, "(");
      return StringUtils.substringAfterLast(methodName, ".");
   }

   public static List<Object[]> getMethodParams(String invokeTarget) {
      String methodStr = StringUtils.substringBetween(invokeTarget, "(", ")");
      if (StringUtils.isEmpty(methodStr)) {
         return null;
      } else {
         String[] methodParams = methodStr.split(",(?=([^\"']*[\"'][^\"']*[\"'])*[^\"']*$)");
         List<Object[]> clazz = new LinkedList();
         String[] var4 = methodParams;
         int var5 = methodParams.length;

         for(int var6 = 0; var6 < var5; ++var6) {
            String methodParam = var4[var6];
            String str = StringUtils.trimToEmpty(methodParam);
            if (StringUtils.startsWithAny(str, new CharSequence[]{"'", "\""})) {
               clazz.add(new Object[]{StringUtils.substring(str, 1, str.length() - 1), String.class});
            } else if (!"true".equalsIgnoreCase(str) && !"false".equalsIgnoreCase(str)) {
               if (StringUtils.endsWith(str, "L")) {
                  clazz.add(new Object[]{Long.valueOf(StringUtils.substring(str, 0, str.length() - 1)), Long.class});
               } else if (StringUtils.endsWith(str, "D")) {
                  clazz.add(new Object[]{Double.valueOf(StringUtils.substring(str, 0, str.length() - 1)), Double.class});
               } else {
                  clazz.add(new Object[]{Integer.valueOf(str), Integer.class});
               }
            } else {
               clazz.add(new Object[]{Boolean.valueOf(str), Boolean.class});
            }
         }

         return clazz;
      }
   }

   public static Class<?>[] getMethodParamsType(List<Object[]> methodParams) {
      Class<?>[] clazz = new Class[methodParams.size()];
      int index = 0;

      for(Iterator var3 = methodParams.iterator(); var3.hasNext(); ++index) {
         Object[] os = (Object[])var3.next();
         clazz[index] = (Class)os[1];
      }

      return clazz;
   }

   public static Object[] getMethodParamsValue(List<Object[]> methodParams) {
      Object[] clazz = new Object[methodParams.size()];
      int index = 0;

      for(Iterator var3 = methodParams.iterator(); var3.hasNext(); ++index) {
         Object[] os = (Object[])var3.next();
         clazz[index] = os[0];
      }

      return clazz;
   }
}
